axon_form library

Enums

FieldType
Enum representing all supported field types in the form
ValidationRuleType
Enum representing all supported field types in the form

Functions

buildError(BuildContext context, String error) Widget