AxonFormDateInputStyle class
- Inheritance
-
- Object
- ThemeExtension<
AxonFormDateInputStyle> - AxonFormDateInputStyle
Constructors
- AxonFormDateInputStyle({InputDecoration? inputDecoration, TextStyle? labelStyle})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputDecoration → InputDecoration?
-
final
- labelStyle → TextStyle?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
{InputDecoration? inputDecoration, TextStyle? labelStyle}) → AxonFormDateInputStyle -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< AxonFormDateInputStyle> ? other, double t) → ThemeExtension<AxonFormDateInputStyle> -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fallback(
BuildContext context) → AxonFormDateInputStyle